@@ -87,11 +87,11 @@ tag_list_get = api.model("TagListGet", {
 
 task_summary = api.model('TaskSummary',
           {
-              'url': ObjectUrl('api_v1.task', attribute='id'),
+              'uri': ObjectUrl('api_v1.task', attribute='id'),
               'id': fields.String,
               'status': fields.String,
               'project': fields.String,
-              'template': ObjectUrl('api_v1.task_template', attribute='id'),
+              'template': ObjectUrl('api_v1.task_template', attribute='template_id'),
               'tags': fields.List(fields.Nested(tag_summary))
           }
 )
@@ -190,11 +190,8 @@ class TaskListAPI(Resource):
         args = self.get_request_parser.parse_args()
         user = args['user']
         project = args['project']
-        template = get_object_from_arg(args['template'],
-                                       models.TaskTemplate,
-                                       models.TaskTemplate.label,
-                                       allow_none=True)
         status = args['status']
+        template = args['template']
         tags = args['tag']
         application_name = args['application_name']
         offset = args['offset']
@@ -202,32 +199,33 @@ class TaskListAPI(Resource):
 
         # Allow retrieval of tasks by user or in general
         query = models.Task.query
+
+        # If not task_real_all, only allow own tasks
         if not current_user.has_permission('task_read_all'):
-            tasks_via_user_query = query.filter(models.Task.users.contains(current_user))
-            tasks_via_group_query = query.filter(models.Task.users_via_group.contains(current_user))
-            query = tasks_via_user_query.union(tasks_via_group_query)
+            user = current_user
+        # If tasks task_read_all allow to specify a user
+        elif user is not None:
+            user = get_object_from_arg(user,
+                                       models.User,
+                                       models.User.username,
+                                       skip_id=True,
+                                       allow_none=False)
+        # Default to current user if no user was specified
+        else:
+            user = current_user
 
-        if user is not None:
-            try:
-                user = int(user)
-                user = models.User.query.filter((models.User.id == user) | (models.User.username == user)).one_or_none()
-            except (TypeError, ValueError):
-                user = models.User.query.filter(models.User.username == user).one_or_none()
-
-            if user is None:
-                print('Could not find user, returning empty list!')
-                abort(404, "Could not find user")
-
-            # Query both tasks via user and via group
-            tasks_via_user_query = query.filter(models.Task.users.contains(user))
-            tasks_via_group_query = query.filter(models.Task.users_via_group.contains(user))
-            query = tasks_via_user_query.union(tasks_via_group_query)
+        # Query both tasks via user and via group
+        tasks_via_user_query = query.filter(models.Task.users.contains(user))
+        tasks_via_group_query = query.filter(models.Task.users_via_group.contains(user))
+        query = tasks_via_user_query.union(tasks_via_group_query)
 
         if template is not None:
+            template = get_object_from_arg(args['template'],
+                                           models.TaskTemplate,
+                                           models.TaskTemplate.label,
+                                           allow_none=False)
             query = query.filter(models.Task.template == template)
-        if args['template'] is not None and template is None:
-            abort(404, 'Could not find template!')
-        
+
         if project is not None:
             query = query.filter(models.Task.project == project)
 
